==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebFormDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataEventArgsDescriptionMetadata } from "./WebFormDataEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebFormDescription } from "./WebFormDescription";
/**
 * @hidden
 */
var WebFormDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFormDescriptionMetadata, _super);
    function WebFormDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFormDescriptionMetadata.b = function (a) {
        if (WebFormDescriptionMetadata.a == null) {
            WebFormDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFormDescriptionMetadata.c(WebFormDescriptionMetadata.a);
        }
        if (a.g(WebFormDescriptionMetadata.a)) {
            return;
        }
        a.s(WebFormDescriptionMetadata.a);
        WebFormDataEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebFormDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Form");
        a.item("Novalidate", "Boolean");
        a.item("SubmitRef", "EventRef::submit");
        a.item("ResetRef", "EventRef::reset");
    };
    WebFormDescriptionMetadata.d = function (a) {
        WebFormDescriptionMetadata.b(a);
        a.u("WebForm", function () { return new WebFormDescription(); });
        a.t("WebForm", WebFormDescriptionMetadata.a);
    };
    WebFormDescriptionMetadata.$t = markType(WebFormDescriptionMetadata, 'WebFormDescriptionMetadata');
    WebFormDescriptionMetadata.a = null;
    return WebFormDescriptionMetadata;
}(Base));
export { WebFormDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebFormDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFormDataEventArgsDescriptionMetadata } from "./WebFormDataEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebFormDescription } from "./WebFormDescription";
/**
 * @hidden
 */
var WebFormDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFormDescriptionMetadata, _super);
    function WebFormDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFormDescriptionMetadata.b = function (a) {
        if (WebFormDescriptionMetadata.a == null) {
            WebFormDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFormDescriptionMetadata.c(WebFormDescriptionMetadata.a);
        }
        if (a.j(WebFormDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFormDescriptionMetadata.a);
        WebFormDataEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebFormDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Form");
        a.item("__tagNameWC", "String:igc-form");
        a.item("Novalidate", "Boolean");
        a.item("SubmitRef", "EventRef::submit");
        a.item("ResetRef", "EventRef::reset");
    };
    WebFormDescriptionMetadata.d = function (a) {
        WebFormDescriptionMetadata.b(a);
        a.aa("WebForm", function () { return new WebFormDescription(); });
        a.z("WebForm", WebFormDescriptionMetadata.a);
    };
    WebFormDescriptionMetadata.$t = markType(WebFormDescriptionMetadata, 'WebFormDescriptionMetadata');
    WebFormDescriptionMetadata.a = null;
    return WebFormDescriptionMetadata;
}(Base));
export { WebFormDescriptionMetadata };
